@@ -49,7 +49,7 @@ def colored(text, color="blue"):
     return text
 
 # constants
-COMPANY_NAME = "Mobilize.Net"
+COMPANY_NAME = "mobilize.net"
 
 # global status values
 max_errors = 1
@@ -231,7 +231,7 @@ def expandvar(str):
 
 opened_connections = []
 
-def log_on(user=None, password=None, account=None, database=None, warehouse=None, role=None, login_timeout=10, authenticator=None):
+def log_on(user=None, password=None, account=None, database=None, warehouse=None, role=None, login_timeout=10, authenticator=None, token=None):
     """Logs on the snowflake database with the credentials, database, warehouse,
     role, login_timeout and authenticator passed parameters.
 
@@ -251,6 +251,8 @@ def log_on(user=None, password=None, account=None, database=None, warehouse=None
         authenticator
             The authenticator supported value to use like SNOWFLAKE, EXTERNALBROWSER,
             SNOWFLAKE_JWT or OAUTH
+        token
+            The OAUTH or JWT token
     """
     global error_code
     global opened_connections
@@ -271,6 +273,8 @@ def log_on(user=None, password=None, account=None, database=None, warehouse=None
         role = get_from_vars_or_args_or_environment(6, "SNOW_ROLE", passed_variables, args)
     if (authenticator is None):
         authenticator = get_from_vars_or_args_or_environment(7, "SNOW_AUTHENTICATOR", passed_variables, args)
+    if (token is None):
+        token = get_from_vars_or_args_or_environment(7, "SNOW_TOKEN", passed_variables, args)
     query_tag = passed_variables.get("SNOW_QUERYTAG", None)
     if (query_tag is None):
         query_tag = getenv("SNOW_QUERYTAG", None)
@@ -279,16 +283,16 @@ def log_on(user=None, password=None, account=None, database=None, warehouse=None
         query_tag = path.basename(frm.filename)
     c = None
     try:
-
         p = {
-                'user' : user,
-                'password' : password,
-                'account' :account,
-                'database' :database,
-                'warehouse' :warehouse,
-                'application' : COMPANY_NAME,
-                'role' : role,
+                'user'          : user,
+                'password'      : password,
+                'account'       : account,
+                'database'      : database,
+                'warehouse'     : warehouse,
+                'application'   : COMPANY_NAME,
+                'role'          : role,
                 'login_timeout' : login_timeout,
+                'token'         : token,
                 'session_parameters' : {
                     'QUERY_TAG': query_tag
                 }
